#!/usr/local/mascot/perl64/bin/perl

use strict;
use warnings;
use autodie;

use LWP::UserAgent;

# Use absolute paths for directories.
my $work_dir = "C:/work/hpylori";
my $mascot_bin_dir = "C:/inetpub/mascot/bin";

my $db_name = "hpylori_split";
my $accession = "CP000241";
my $filename = "$accession.fasta";

# Step 1: download the file.
chdir $work_dir;
download_from_EBI($accession, $filename);

# Step 2: split it.
chdir $mascot_bin_dir;
system('../perl64/bin/perl', 'splitter.pl', join('/', $work_dir, $filename));
print "$accession has been split\n";

# Step 3: schedule an update task.
chdir $mascot_bin_dir;
system('../perl64/bin/perl', 'dbman_add_task.pl', $db_name);
print "Update task scheduled for $db_name\n";

# All done.
exit 0;


# Helper function that downloads a file.
sub download_from_EBI {
    my ($accession, $filename) = @_;

    my $url = "https://www.ebi.ac.uk/ena/data/view/${accession}&display=fasta&download=fasta&filename=${filename}";
    print "Downloading '$url'\n";

    my $ua = LWP::UserAgent->new;
    $ua->env_proxy;

    my $response = $ua->mirror($url, $filename);

    if (not $response->is_success) {
        if ($response->code == 304) {
            print "Remote file has not changed, so nothing needs to be done\n";
            exit 0;
        } else {
            die $response->status_line;
        }
    }

    print "Saved as '$filename'\n";
}
